/* Copyright (C) Gabor Karsay 2017 <gabor.karsay@gmx.at>
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#include <glib.h>
#include <pt-progress-dialog.h>


static void
progressdialog_new (void)
{
	PtProgressDialog *testdialog;
	testdialog = pt_progress_dialog_new (NULL);
	g_assert (PT_IS_PROGRESS_DIALOG (testdialog));
	pt_progress_dialog_set_progress (testdialog, 0.5);
	gtk_widget_destroy (GTK_WIDGET (testdialog));
}

int
main (int argc, char *argv[])
{
	g_test_init (&argc, &argv, NULL);

	g_test_add_func ("/progressdialog/new", progressdialog_new);
	gtk_init (NULL, NULL);

	return g_test_run ();
}
